[Libreoffice-commits] core.git: bean/qa

Noel Grandin noel at peralex.com
Wed Apr 17 01:50:02 PDT 2013


 bean/qa/complex/bean/OOoBeanTest.java |    8 ++++----
 bean/qa/complex/bean/WriterFrame.java |    4 ++--
 2 files changed, 6 insertions(+), 6 deletions(-)

New commits:
commit cb6b6e286cf4664c0036560908ec28f3bba3aaa6
Author: Noel Grandin <noel at peralex.com>
Date:   Wed Apr 17 10:49:20 2013 +0200

    Fix for method name change
    
    In commit
      43debfae8326ad98f9d130aa450f59ad49577d55
      "General cleanup of OfficeBeans"
    In class
       com.sun.star.comp.beans.OOoBean,
    the method
       aquireSystemWindow
    changed name to
       acquireSystemWindow
    
    Change-Id: I5a9a16c1374d7dbc828ee2fa76c193b207881415

diff --git a/bean/qa/complex/bean/WriterFrame.java b/bean/qa/complex/bean/WriterFrame.java
index 525ddf7..3162646 100644
--- a/bean/qa/complex/bean/WriterFrame.java
+++ b/bean/qa/complex/bean/WriterFrame.java
@@ -61,7 +61,7 @@ class WriterFrame extends java.awt.Frame
                 pack();
                 setBounds(x, y, width, height);
                 setVisible(true);
-                m_bean.aquireSystemWindow();
+                m_bean.acquireSystemWindow();
             }
         }
         catch (Exception e)
@@ -193,7 +193,7 @@ class WriterFrame extends java.awt.Frame
     public void addOOoBean() throws Exception
     {
         add(m_bean, BorderLayout.CENTER);
-        m_bean.aquireSystemWindow();
+        m_bean.acquireSystemWindow();
         validate();
     }
 


More information about the Libreoffice-commits mailing list
diff --git a/bean/qa/complex/bean/OOoBeanTest.java b/bean/qa/complex/bean/OOoBeanTest.java
index ae256dd..c72e18e 100644
--- a/bean/qa/complex/bean/OOoBeanTest.java
+++ b/bean/qa/complex/bean/OOoBeanTest.java
@@ -302,7 +302,7 @@ public class OOoBeanTest
         }
     }
 
     /** Test repeated OOoBean.aquireSystemWindow and OOoBean.releaseSystemWindow
      * calls.
      * @throws Exception
      */
@@ -316,7 +316,7 @@ public class OOoBeanTest
             for (int i = 0; i < 100; i++)
             {
                 b.releaseSystemWindow();
-                b.aquireSystemWindow();
+                b.acquireSystemWindow();
             }
             if (!f.checkUnoFramePosition())
             {
@@ -419,7 +419,7 @@ public class OOoBeanTest
                     bean.releaseSystemWindow();
                     frame.remove(bean);
                     frame.add(bean, BorderLayout.CENTER);
-                    bean.aquireSystemWindow();
+                    bean.acquireSystemWindow();
                 }
 
                 if (!isWindows())
@@ -504,7 +504,7 @@ public class OOoBeanTest
                             try {
 
                             frame.add(bean, BorderLayout.CENTER);
-                            bean.aquireSystemWindow();
+                            bean.acquireSystemWindow();
                             frame.validate();
                             } catch (Exception e) {
                                 e.printStackTrace();
@@ -302,7 +302,7 @@ public class OOoBeanTest
     }
 
-    /** Test repeated OOoBean.aquireSystemWindow and OOoBean.releaseSystemWindow
+    /** Test repeated OOoBean.acquireSystemWindow and OOoBean.releaseSystemWindow
      * calls.
      * @throws Exception